======================
What is RecaptureDocs?
======================

RecaptureDocs is an answer to the common problem of having only a
scanned version of a document when one needs the digital text.
We provide a simple web interface for uploading a scanned
image and receiving the text contained in that image.

It is *not* an OCR system. While Optical Character Recignition (OCR) is
effective for some situations
such as for searching for certain keywords in a document, OCR is often
inadequate for recreating a digital document from an image. Especially
if the scanned image is of less-than-ideal quality, the time to
correct OCR mistakes can often exceed the time to retype the document
anyway.

What RecaptureDocs does is employ a dynamic team of typists to retype
each page by hand. This provides an extremely high level of quality, as
each word is read and re-keyed by a human operator.

What kinds of documents can RecaptureDocs handle?
-------------------------------------------------

The site currently accepts any PDF document, but that doesn't mean that a
typist can re-key just any content. RecaptureDocs works best with prose or
other narrative text such as legal documents or handwritten notes of about 500
words per page or less. Results from other
document types, such as blueprints, datasheets, fine-print, or other
non-English content are not guaranteed.

How does it work?
-----------------

RecaptureDocs is designed to be as simple as possible. No account is
necessary. Simply upload a PDF, complete payment for that document, and
wait for the content to be rekeyed.

When you upload your PDF, our proprietary system separates out the
images of the PDF and allocates them to jobs for typists to do. Behind
the scenes, we employ workers from Amazon's `Mechanical Turk
<https://www.mturk.com/mturk/welcome>`_, their marketplace for work.
Typists have access to only one page at a time, which means a multi-page
document will be processed by multiple typists in parallel, providing
you with a rapid turnaround on your document.

The entire process is automated. As soon as you complete payment, the
pages are made available for retyping at an enticing rate. Typists seek
out these jobs and enjoy the work.

When all of the pages are complete, the status page for your document
will be updated with a link to the text to your document. From this
page, you can copy the text and paste it into your favorite word
processor or e-mail.

What if I lose the link to my status page?
------------------------------------------

Since RecaptureDocs keeps no accounts for the uploaded jobs, there is
no association between you and your document. If you lost your link to
your document, simply upload the same document again (it must be the
exact same file, not another scan or otherwise altered version).
RecaptureDocs will recognize that the document is the same as one you
have already paid for and will take you to the status page, where you
may retrieve the text once again.
